@@ -54,16 +54,19 @@ class CVTrafficRegenerator(object):
                         continue
                     body[str(k).replace("http-req-body-", "")] = v
             request["header"] = header
-
+            to_skip = False
             for param in params_to_add:
                 if param["type"] == "string":
                     value = ''.join(random.choices(string.ascii_uppercase + string.digits, k=7))
                 elif param["type"] in ["number", "integer"]:
                     value = random.randint(1, 9999)
-                body.update({param["name"]: value})
-
+                if param["name"] not in body:
+                    body.update({param["name"]: value})
+                else:
+                    to_skip = True
             request["body"] = body
-            cv_requests.append(request)
+            if not to_skip:
+                cv_requests.append(request)
         return cv_requests
 
     def _trigger_requests(self, cv_requests):
